from django.db import models

from django.core.mail import EmailMessage
from django.template.loader import render_to_string
from django.conf import settings

class Home(models.Model):
    MEDIA_CHOICES = (
        ('video', 'Video'),
        ('photo', 'Photo'),
    )
    title = models.CharField(max_length=100)
    media_type = models.CharField(max_length=10, choices=MEDIA_CHOICES, default='photo')
    media_file = models.FileField(upload_to='media/')

    def __str__(self):
        return self.title

class Group_member(models.Model):
    name = models.CharField(max_length=100)
    designation = models.CharField(max_length=100)
    description = models.TextField()
    photo = models.ImageField(upload_to='photos/')

    def __str__(self):
        return self.name

class Presentation(models.Model):
    PRESENTATION_TYPES = (
        ('advertising', 'Advertising'),
        ('feature_films', 'Feature Films'),
        ('web_series', 'Web Series'),
        ('music_videos', 'Music Videos'),
        ('international_collaborations', 'International Collaborations'),
        ('documentation', 'Documentation'),
    )

    title = models.CharField(max_length=100, blank= True)
    presentation_type = models.CharField(max_length=30, choices=PRESENTATION_TYPES)
    media_files = models.ManyToManyField('File', related_name='presentations',blank= True)
    description = models.TextField()

    def __str__(self):
        return self.title

class File(models.Model):
    MEDIA_CHOICES = (
        ('video', 'Video'),
        ('photo', 'Photo'),
    )
    media_type = models.CharField(max_length=10, choices=MEDIA_CHOICES)
    media_file = models.FileField(upload_to='presentations/')

    def __str__(self):
        return f"{self.media_type}: {self.media_file}"

class Contract(models.Model):
    name = models.CharField(max_length=100)
    email = models.EmailField()
    company = models.CharField(max_length=100)
    message = models.TextField()
    
    def __str__(self):
        return f"Message from {self.name}"
    
    def send_welcome_message(self):
        subject = 'Welcome to Our Website'
        from_email = settings.DEFAULT_FROM_EMAIL
        to_email = [self.email]

        context = {'name': self.name}
        welcome_message = render_to_string('email/welcome_message.txt', context)

        email = EmailMessage(subject, welcome_message, from_email, to_email)

        email.send()

    def notify_admin(self):
        subject = 'New Contract Form Submission'
        from_email = self.email
        to_email = [settings.ADMIN_EMAIL]

        context = {'contract': self}
        notification_message = render_to_string('email/notification_message.txt', context)
        
        email = EmailMessage(subject, notification_message, from_email, to_email)
        
        email.send()